@@ -89,6 +89,7 @@
 
 	# Handle auto-assigning
 	if ( ( NEW_ == $t_bug_data->status )
+	  && ( $t_bug_data->status == $t_old_bug_status )
 	  && ( 0 != $t_bug_data->handler_id )
 	  && ( ON == config_get( 'auto_set_status_to_assigned' ) ) ) {
 		$t_bug_data->status = config_get( 'bug_assigned_status' );
@@ -109,7 +110,6 @@
 	$t_related_custom_field_ids = custom_field_get_linked_ids( $t_bug_data->project_id );
 	foreach( $t_related_custom_field_ids as $t_id ) {
 		$t_def = custom_field_get_definition( $t_id );
-		$t_custom_field_value = gpc_get_custom_field( "custom_field_$t_id", $t_def['type'], null );
 
 		# Only update the field if it would have been display for editing
 		if( !( ( ! $f_update_mode && $t_def['require_' . $t_custom_status_label] ) ||
@@ -119,22 +119,24 @@
 			continue;
 		}
 
-		# Only update the field if it is posted 
-		#  ( will fail in custom_field_set_value(), if it was required )
-		if ( $t_custom_field_value === null ) {
-			continue;
-		}
-
 		# Do not set custom field value if user has no write access.
 		if( !custom_field_has_write_access( $t_id, $f_bug_id ) ) {
 			continue;
 		}
 
-		if ( $t_def['require_' . $t_custom_status_label] && ( gpc_get_custom_field( "custom_field_$t_id", $t_def['type'], '' ) == '' ) ) {
+		if ( $t_def['require_' . $t_custom_status_label] && !gpc_isset_custom_field( $t_id, $t_def['type'] ) ) {
 			error_parameters( lang_get_defaulted( custom_field_get_field( $t_id, 'name' ) ) );
 			trigger_error( ERROR_EMPTY_FIELD, ERROR );
 		}
-		if ( !custom_field_set_value( $t_id, $f_bug_id, $t_custom_field_value ) ) {
+
+		# Only update the field if it is posted, 
+		#	or if it is empty, and the current value isn't the default 
+		if ( !gpc_isset_custom_field( $t_id, $t_def['type'] ) && 
+				( custom_field_get_value( $t_id, $f_bug_id ) == $t_def['default_value'] ) ) {
+			continue;
+		}
+
+		if ( !custom_field_set_value( $t_id, $f_bug_id, gpc_get_custom_field( "custom_field_$t_id", $t_def['type'], NULL ) ) ) {
 			error_parameters( lang_get_defaulted( custom_field_get_field( $t_id, 'name' ) ) );
 			trigger_error( ERROR_CUSTOM_FIELD_INVALID_VALUE, ERROR );
 		}
