@@ -150,9 +150,18 @@
 	#   'memcached' -> Memcached storage sessions
 	$g_session_handler = 'php';
 
+	# Session key name.  Should be unique between multiple installations to prevent conflicts.
+	$g_session_key = 'MantisBT';
+
 	# Session save path.  If false, uses default value as set by session handler.
 	$g_session_save_path = false;
 
+	# Form security validation.
+	# This protects against Cross-Site Request Forgery, but some proxy servers may
+	# not correctly work with this option enabled because they cache pages incorrectly.
+	# WARNING: Disabling this IS a security risk!!
+	$g_form_security_validation = ON;
+
 	#############################
 	# Configuration Settings
 	#############################
@@ -163,7 +172,7 @@
 	$g_global_settings = array(
 		'_table$', 'cookie', '^db_', 'hostname', 'database_name', 'session_handler',
 		'_path$', 'use_iis', 'language', 'use_javascript', 'display_errors', 'stop_on_errors', 'login_method', '_file$',
-		'anonymous', 'content_expire', 'html_valid_tags', 'custom_headers', 'rss_key_seed'
+		'anonymous', 'content_expire', 'html_valid_tags', 'custom_headers', 'rss_key_seed', 'form_security_',
 	);
 
 	#############################
@@ -378,6 +387,7 @@
 	# list the choices that the users are allowed to choose
 	$g_language_choices_arr	= array(
 		'auto',
+		'arabic',
 		'bulgarian',
 		'catalan',
 		'chinese_simplified',
@@ -419,6 +429,7 @@
 
 	# Browser language mapping for 'auto' language selection
 	$g_language_auto_map = array(
+		'ar' => 'arabic',
 		'bg' => 'bulgarian',
 		'ca' => 'catalan',
 		'zh-cn, zh-sg, zh' => 'chinese_simplified',
@@ -993,7 +1004,7 @@
 	# list of filetypes to view inline. This is a string of extentions separated by commas
 	# This is used when downloading an attachment.  Rather than downloading, the attachment
 	# is viewed in the browser.
-	$g_inline_file_exts = 'gif,png';
+	$g_inline_file_exts = 'bmp,png,gif,jpg,jpeg';
 
 	# access level needed to download bug attachments
 	$g_download_attachments_threshold	= VIEWER;
