@@ -194,6 +194,9 @@
         if (auth_clear_cookies()) {
             helper_clear_pref_cookies();
         }
+
+		session_clean();
+
 		return true;
 	}
 
@@ -516,7 +519,7 @@
 
 <table class="width50 center">
 <tr>
-	<td class="form-title"><?php echo lang_get( 'reauthenticate_title' ); ?></td>
+	<td class="form-title" colspan="2"><?php echo lang_get( 'reauthenticate_title' ); ?></td>
 </tr>
 
 <tr class="row-1">
