@@ -102,7 +102,7 @@
 		}	
 		
 		if( !is_int( $p_bug_datebase_result['date_submitted'] ) )
-			$p_bug_datebase_result['date_submitted']	= db_unixtimestamp( $p_bug_datebase_result['date_submitted']['date_submitted'] );
+			$p_bug_datebase_result['date_submitted']	= db_unixtimestamp( $p_bug_datebase_result['date_submitted'] );
 		if( !is_int( $p_bug_datebase_result['last_updated'] ) )
 			$p_bug_datebase_result['last_updated']	= db_unixtimestamp( $p_bug_datebase_result['last_updated'] );
 		$g_cache_bug[ $p_bug_datebase_result['id'] ] = $p_bug_datebase_result;
@@ -1264,9 +1264,6 @@
 					# the relationship type is already set. Nothing to do
 				}
 				else if ( $t_id_relationship > 0 ) {
-					# there is already a relationship between them -> we have to update it and not to add a new one
-					helper_ensure_confirmed( lang_get( 'replace_relationship_sure_msg' ), lang_get( 'replace_relationship_button' ) );
-
 					# Update the relationship
 					relationship_update( $t_id_relationship, $p_bug_id, $p_duplicate_id, BUG_DUPLICATE );
 
