@@ -1,12 +1,24 @@
 <?php
-	# Mantis - a php based bugtracking system
-	# Copyright (C) 2000 - 2002  Kenzaburo Ito - kenito@300baud.org
-	# Copyright (C) 2002 - 2007  Mantis Team   - mantisbt-dev@lists.sourceforge.net
-	# This program is distributed under the terms and conditions of the GPL
-	# See the README and LICENSE files for details
+# Mantis - a php based bugtracking system
+
+# Copyright (C) 2000 - 2002  Kenzaburo Ito - kenito@300baud.org
+# Copyright (C) 2002 - 2007  Mantis Team   - mantisbt-dev@lists.sourceforge.net
+
+# Mantis is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation, either version 2 of the License, or
+# (at your option) any later version.
+#
+# Mantis is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with Mantis.  If not, see <http://www.gnu.org/licenses/>.
 
 	# --------------------------------------------------------
-	# $Id: custom_field_api.php,v 1.57.12.2 2007/04/01 08:00:38 vboctor Exp $
+	# $Id: custom_field_api.php,v 1.66.2.1 2007-10-13 22:35:21 giallu Exp $
 	# --------------------------------------------------------
 
 	$t_core_dir = dirname( __FILE__ ).DIRECTORY_SEPARATOR;
@@ -34,6 +46,8 @@
 	#   being spoofed if register_globals is turned on
 
 	$g_cache_custom_field = array();
+	$g_cache_cf_list = NULL;
+	$g_cache_cf_linked = array();
 
 	# Cache a custom field row if necessary and return the cached copy
 	#  If the second parameter is true (default), trigger an error
@@ -243,11 +257,12 @@
 
 		$c_name = db_prepare_string( trim( $p_name ) );
 
-		if ( is_blank( $p_name ) ) {
+		if ( is_blank( $c_name ) ) {
+			error_parameters( 'name' );
 			trigger_error( ERROR_EMPTY_FIELD, ERROR );
 		}
 
-		custom_field_ensure_name_unique( $p_name );
+		custom_field_ensure_name_unique( $c_name );
 
 		$t_custom_field_table = config_get( 'mantis_custom_field_table' );
 		$query = "INSERT INTO $t_custom_field_table
@@ -288,8 +303,12 @@
 		$c_require_resolved = db_prepare_bool( 	 $p_def_array['require_resolved'] );
 		$c_require_closed	= db_prepare_bool( 	 $p_def_array['require_closed']   );
 
-		if (( is_blank( $c_name ) ) ||
-			( $c_access_level_rw < $c_access_level_r ) ||
+		if ( is_blank( $c_name ) ) {
+			error_parameters( 'name' );
+			trigger_error( ERROR_EMPTY_FIELD, ERROR );
+		}
+
+		if (( $c_access_level_rw < $c_access_level_r ) ||
 			( $c_length_min < 0 ) ||
 			( ( $c_length_max != 0 ) && ( $c_length_min > $c_length_max ) ) ) {
 			trigger_error( ERROR_CUSTOM_FIELD_INVALID_DEFINITION, ERROR );
@@ -299,7 +318,6 @@
 			trigger_error( ERROR_CUSTOM_FIELD_INVALID_DEFINITION, ERROR );
 		}
 
-
 		if ( !custom_field_is_name_unique( $c_name, $c_field_id ) ) {
 			trigger_error( ERROR_CUSTOM_FIELD_NAME_NOT_UNIQUE, ERROR );
 		}
@@ -587,6 +605,10 @@
 	# Get the id of the custom field with the specified name.
 	# false is returned if no custom field found with the specified name.
 	function custom_field_get_id_from_name( $p_field_name, $p_truncated_length = null ) {
+		if ( $p_field_name == '' ) {
+		  return false;
+		}
+
 		$t_custom_field_table = config_get( 'mantis_custom_field_table' );
 
 		$c_field_name = db_prepare_string( $p_field_name );
@@ -616,88 +638,103 @@
 	#
 	# The ids will be sorted based on the sequence number associated with the binding
 	function custom_field_get_linked_ids( $p_project_id = ALL_PROJECTS ) {
-		$t_custom_field_table			= config_get( 'mantis_custom_field_table' );
-		$t_custom_field_project_table	= config_get( 'mantis_custom_field_project_table' );
+	global $g_cache_cf_linked;
+        
+        if ( ! isset( $g_cache_cf_linked[$p_project_id] ) ) {
+        
+     		$t_custom_field_table			= config_get( 'mantis_custom_field_table' );
+     		$t_custom_field_project_table	= config_get( 'mantis_custom_field_project_table' );
 
-		if ( ALL_PROJECTS == $p_project_id ) {
-            $t_project_user_list_table = config_get( 'mantis_project_user_list_table' );
-            $t_project_table = config_get( 'mantis_project_table' );
-            $t_user_table = config_get( 'mantis_user_table' );
-            $t_user_id = auth_get_current_user_id();
-            $t_pub = VS_PUBLIC;
-            $t_priv = VS_PRIVATE;
+    		if ( ALL_PROJECTS == $p_project_id ) {
+                $t_project_user_list_table = config_get( 'mantis_project_user_list_table' );
+                $t_project_table = config_get( 'mantis_project_table' );
+                $t_user_table = config_get( 'mantis_user_table' );
+                $t_user_id = auth_get_current_user_id();
+                $t_pub = VS_PUBLIC;
+                $t_priv = VS_PRIVATE;
             
-            $t_private_access = config_get( 'private_project_threshold' );
-            if ( is_array( $t_private_access ) ) {
-                if ( 1 == count( $t_private_access ) ) {
-				    $t_access_clause = "= " . array_shift( $t_private_access ) . " ";
+                $t_private_access = config_get( 'private_project_threshold' );
+                if ( is_array( $t_private_access ) ) {
+                    if ( 1 == count( $t_private_access ) ) {
+    				    $t_access_clause = "= " . array_shift( $t_private_access ) . " ";
+                    } else {
+                        $t_access_clause = "IN (" . implode( ',', $t_private_access ) . ")";
+                    }
                 } else {
-                    $t_access_clause = "IN (" . implode( ',', $t_private_access ) . ")";
-                }
-            } else {
-                $t_access_clause = ">= $t_private_access ";
-            }			
+                    $t_access_clause = ">= $t_private_access ";
+                }			
 
             
-            # select only the ids that the user has some access to 
-            #  e.g., all fields in public projects, or private projects where the user is listed
-            #    or private projects where the user is implicitly listed
-            $query = "SELECT cft.id as id, cft.name as name
-                FROM $t_custom_field_table as cft, $t_user_table ut, $t_project_table pt, $t_custom_field_project_table cfpt
-                    LEFT JOIN $t_project_user_list_table pult 
-                        on cfpt.project_id = pult.project_id and pult.user_id = $t_user_id
-                WHERE cft.id = cfpt.field_id AND cfpt.project_id = pt.id AND ut.id = $t_user_id AND 
-                    ( pt.view_state = $t_pub OR 
-                    ( pt.view_state = $t_priv and pult.user_id = $t_user_id ) OR 
-                    ( pult.user_id is null and ut.access_level $t_access_clause ) )
-                GROUP BY cft.id, cft.name
-                ORDER BY cft.name ASC";
-		} else {
-            if ( is_array( $p_project_id ) ) {
-                if ( 1 == count( $p_project_id ) ) {
-				    $t_project_clause = "= " . array_shift( $p_project_id ) . " ";
+                # select only the ids that the user has some access to 
+                #  e.g., all fields in public projects, or private projects where the user is listed
+                #    or private projects where the user is implicitly listed
+                $query = "SELECT cft.id as id, cft.name as name
+                    FROM $t_custom_field_table as cft, $t_user_table ut, $t_project_table pt, $t_custom_field_project_table cfpt
+                        LEFT JOIN $t_project_user_list_table pult 
+                            on cfpt.project_id = pult.project_id and pult.user_id = $t_user_id
+                    WHERE cft.id = cfpt.field_id AND cfpt.project_id = pt.id AND ut.id = $t_user_id AND 
+                        ( pt.view_state = $t_pub OR 
+                        ( pt.view_state = $t_priv and pult.user_id = $t_user_id ) OR 
+                        ( pult.user_id is null and ut.access_level $t_access_clause ) )
+                    GROUP BY cft.id, cft.name
+                    ORDER BY cft.name ASC";
+    		} else {
+                if ( is_array( $p_project_id ) ) {
+                    if ( 1 == count( $p_project_id ) ) {
+    				    $t_project_clause = "= " . array_shift( $p_project_id ) . " ";
+                    } else {
+                        $t_project_clause = "IN (" . implode( ',', $p_project_id ) . ")";
+                    }
                 } else {
-                    $t_project_clause = "IN (" . implode( ',', $p_project_id ) . ")";
-                }
-            } else {
-                $t_project_clause = "= $p_project_id ";
-            }			
-			$query = "SELECT cft.id, cft.name, cfpt.sequence
+                    $t_project_clause = "= $p_project_id ";
+                }			
+    			$query = "SELECT cft.id, cft.name, cfpt.sequence
 					  FROM $t_custom_field_table cft, $t_custom_field_project_table cfpt
 					  WHERE cfpt.project_id $t_project_clause AND
 							cft.id = cfpt.field_id
 					  ORDER BY sequence ASC, name ASC";
-		}
-		$result = db_query( $query );
-		$t_row_count = db_num_rows( $result );
-		$t_ids = array();
+    		}
+    		$result = db_query( $query );
+    		$t_row_count = db_num_rows( $result );
+    		$t_ids = array();
 
-		for ( $i=0 ; $i < $t_row_count ; $i++ ) {
-			$row = db_fetch_array( $result );
-
-			array_push( $t_ids, $row['id'] );
-		}
+    		for ( $i=0 ; $i < $t_row_count ; $i++ ) {
+    			$row = db_fetch_array( $result );
 
+    			array_push( $t_ids, $row['id'] );
+    		}
+    		$g_cache_cf_linked[$p_project_id] = $t_ids;
+    	} else {
+    		$t_ids = $g_cache_cf_linked[$p_project_id];
+        }
+        
 		return $t_ids;
 	}
 
 	# --------------------
 	# Return an array all custom field ids sorted by name
 	function custom_field_get_ids( ) {
-		$t_custom_field_table			= config_get( 'mantis_custom_field_table' );
-		$query = "SELECT id, name
+        global $g_cache_cf_list;
+       
+        if ( $g_cache_cf_list === NULL ) {
+            $t_custom_field_table			= config_get( 'mantis_custom_field_table' );
+            $query = "SELECT id, name
 				  FROM $t_custom_field_table
 				  ORDER BY name ASC";
-		$result = db_query( $query );
-		$t_row_count = db_num_rows( $result );
-		$t_ids = array();
+            $result = db_query( $query );
+            $t_row_count = db_num_rows( $result );
+            $t_ids = array();
 
-		for ( $i=0 ; $i < $t_row_count ; $i++ ) {
-			$row = db_fetch_array( $result );
+            for ( $i=0 ; $i < $t_row_count ; $i++ ) {
+                $row = db_fetch_array( $result );
 
-			array_push( $t_ids, $row['id'] );
-		}
+                array_push( $t_ids, $row['id'] );
+            }
+            $g_cache_cf_list = $t_ids;
 
+        } else {
+            $t_ids = $g_cache_cf_list;
+        }
 		return $t_ids;
 	}
 
@@ -907,22 +944,40 @@
 		$t_length_max		= $row['length_max'];
 		$t_default_value	= $row['default_value'];
 
-		# check for valid value
-		if ( !is_blank( $t_valid_regexp ) ) {
-			if ( !ereg( $t_valid_regexp, $p_value ) ) {
-				return false;
-			}
+		$t_valid = true;
+		$t_length = strlen( $p_value );
+		switch ($t_type) {
+			case CUSTOM_FIELD_TYPE_STRING:
+				// validate against regexp
+				if( !is_blank( $t_valid_regexp ) && !is_blank( $p_value ) ) {
+					$t_valid &= ereg( $t_valid_regexp, $p_value );
+				}
+				// check string length
+				$t_valid &= ( 0 == $t_length_min ) || ( $t_length > $t_length_min );
+				$t_valid &= ( 0 == $t_length_max ) || ( $t_length <= $t_length_max );
+				break;
+			case CUSTOM_FIELD_TYPE_NUMERIC:
+				$t_valid &= ( $t_length == 0 ) || is_numeric( $p_value );
+				break;
+			case CUSTOM_FIELD_TYPE_FLOAT:
+				// handle both number and number with decimal
+				$t_valid &= ( $t_length == 0 ) || is_numeric( $p_value ) || is_float( $p_value );
+				break;
+			case CUSTOM_FIELD_TYPE_DATE:
+				// gpc_get_cf for date returns the value from strftime
+				// either false (php >= 5.1)  or -1 (php < 5.1) for failure
+				$t_valid &= ( $p_value == null ) || ( ( $p_value !== false ) && ( $p_value > 0 ) );
+				break;
+			case CUSTOM_FIELD_TYPE_ENUM:
+			case CUSTOM_FIELD_TYPE_EMAIL:
+			case CUSTOM_FIELD_TYPE_CHECKBOX:
+			case CUSTOM_FIELD_TYPE_LIST:
+			case CUSTOM_FIELD_TYPE_MULTILIST:
+			case CUSTOM_FIELD_TYPE_RADIO:
+			default:
+			break;
 		}
-
-		if ( strlen( $p_value ) < $t_length_min ) {
-			return false;
-		}
-
-		if ( ( 0 != $t_length_max ) && ( strlen( $p_value ) > $t_length_max ) ) {
-			return false;
-		}
-
-		return true;
+		return $t_valid;
 	}
 
 	# --------------------
@@ -1044,40 +1099,11 @@
 	function custom_field_set_value( $p_field_id, $p_bug_id, $p_value ) {
 		$c_field_id	= db_prepare_int( $p_field_id );
 		$c_bug_id	= db_prepare_int( $p_bug_id );
+		$c_value = db_prepare_string( $p_value );
 
 		custom_field_ensure_exists( $p_field_id );
 
-		$t_custom_field_table = config_get( 'mantis_custom_field_table' );
-		$query = "SELECT name, type, possible_values, valid_regexp,
-				  access_level_rw, length_min, length_max, default_value
-				  FROM $t_custom_field_table
-				  WHERE id='$c_field_id'";
-		$result = db_query( $query );
-		$row = db_fetch_array( $result );
-
-		$t_name				= $row['name'];
-		$t_type				= $row['type'];
-		$t_possible_values	= $row['possible_values'];
-		$t_valid_regexp		= $row['valid_regexp'];
-		$t_access_level_rw	= $row['access_level_rw'];
-		$t_length_min		= $row['length_min'];
-		$t_length_max		= $row['length_max'];
-		$t_default_value	= $row['default_value'];
-
-		$c_value	= db_prepare_string( custom_field_value_to_database( $p_value, $t_type ) );
-
-		# check for valid value
-		if ( !is_blank( $t_valid_regexp ) ) {
-			if ( !ereg( $t_valid_regexp, $p_value ) ) {
-				return false;
-			}
-		}
-
-		if ( strlen( $p_value ) < $t_length_min ) {
-			return false;
-		}
-
-		if ( ( 0 != $t_length_max ) && ( strlen( $p_value ) > $t_length_max ) ) {
+		if ( ! custom_field_validate( $p_field_id, $p_value ) ) {
 			return false;
 		}
 
@@ -1085,6 +1111,9 @@
 			return false;
 		}
 
+		$t_name = custom_field_get_field( $p_field_id, 'name' );
+		$t_type = custom_field_get_field( $p_field_id, 'type' );
+
 		$t_custom_field_string_table = config_get( 'mantis_custom_field_string_table' );
 
 		# do I need to update or insert this value?
@@ -1181,15 +1210,15 @@
 			}
 
 			if ( $p_field_def['type'] == CUSTOM_FIELD_TYPE_MULTILIST ) {
-				echo '<select name="custom_field_' . $t_id . '[]" size="' . $t_list_size . '" multiple>';
+				echo '<select ', helper_get_tab_index(), ' name="custom_field_' . $t_id . '[]" size="' . $t_list_size . '" multiple="multiple">';
 			} else {
-				echo '<select name="custom_field_' . $t_id . '" size="' . $t_list_size . '">';
+				echo '<select ', helper_get_tab_index(), ' name="custom_field_' . $t_id . '" size="' . $t_list_size . '">';
 			}
 
 			$t_selected_values = explode( '|', $t_custom_field_value );
  			foreach( $t_values as $t_option ) {
-				if( in_array( $t_option, $t_selected_values ) ) {
- 					echo '<option value="' . $t_option . '" selected> ' . $t_option . '</option>';
+				if( in_array( $t_option, $t_selected_values, true ) ) {
+ 					echo '<option value="' . $t_option . '" selected="selected"> ' . $t_option . '</option>';
  				} else {
  					echo '<option value="' . $t_option . '">' . $t_option . '</option>';
  				}
@@ -1200,9 +1229,9 @@
 			$t_values = explode( '|', custom_field_prepare_possible_values( $p_field_def['possible_values'] ) );
 			$t_checked_values = explode( '|', $t_custom_field_value );
 			foreach( $t_values as $t_option ) {
-				echo '<input type="checkbox" name="custom_field_' . $t_id . '[]"';
-				if( in_array( $t_option, $t_checked_values ) ) {
-					echo ' value="' . $t_option . '" checked>&nbsp;' . $t_option . '&nbsp;&nbsp;';
+				echo '<input ', helper_get_tab_index(), ' type="checkbox" name="custom_field_' . $t_id . '[]"';
+				if( in_array( $t_option, $t_checked_values, true ) ) {
+					echo ' value="' . $t_option . '" checked="checked">&nbsp;' . $t_option . '&nbsp;&nbsp;';
 				} else {
 					echo ' value="' . $t_option . '">&nbsp;' . $t_option . '&nbsp;&nbsp;';
 				}
@@ -1212,7 +1241,7 @@
 		case CUSTOM_FIELD_TYPE_FLOAT:
 		case CUSTOM_FIELD_TYPE_EMAIL:
 		case CUSTOM_FIELD_TYPE_STRING:
-			echo '<input type="text" name="custom_field_' . $t_id . '" size="80"';
+			echo '<input ', helper_get_tab_index(), ' type="text" name="custom_field_' . $t_id . '" size="80"';
 			if( 0 < $p_field_def['length_max'] ) {
 				echo ' maxlength="' . $p_field_def['length_max'] . '"';
 			} else {
@@ -1243,7 +1272,8 @@
 			case CUSTOM_FIELD_TYPE_LIST:
 			case CUSTOM_FIELD_TYPE_MULTILIST:
 			case CUSTOM_FIELD_TYPE_CHECKBOX:
-				return str_replace( '|', ', ', $t_custom_field_value );
+				// strip possible start and end markers before converting markers to commas
+				return str_replace( '|', ', ', substr( str_replace( "||", "|", '|' . $t_custom_field_value . '|' ), 1, -1 ) );
 				break;
 			case CUSTOM_FIELD_TYPE_DATE:
 				if ($t_custom_field_value != null) {
@@ -1279,7 +1309,8 @@
 			case CUSTOM_FIELD_TYPE_LIST:
 			case CUSTOM_FIELD_TYPE_MULTILIST:
 			case CUSTOM_FIELD_TYPE_CHECKBOX:
-				return str_replace( '|', ', ', $p_value );
+				// strip start and end markers before converting markers to commas
+				return str_replace( '|', ', ', substr( str_replace( "||", "|", '|' . $p_value . '|' ), 1, -1 ) );
 				break;
 			case CUSTOM_FIELD_TYPE_DATE:
 				if ($p_value != null) {
