@@ -1,22 +1,38 @@
 <?php
-	# Mantis - a php based bugtracking system
-	# Copyright (C) 2000 - 2002  Kenzaburo Ito - kenito@300baud.org
-	# Copyright (C) 2002 - 2004  Mantis Team   - mantisbt-dev@lists.sourceforge.net
-	# This program is distributed under the terms and conditions of the GPL
-	# See the README and LICENSE files for details
+# Mantis - a php based bugtracking system
+
+# Copyright (C) 2000 - 2002  Kenzaburo Ito - kenito@300baud.org
+# Copyright (C) 2002 - 2007  Mantis Team   - mantisbt-dev@lists.sourceforge.net
+
+# Mantis is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation, either version 2 of the License, or
+# (at your option) any later version.
+#
+# Mantis is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with Mantis.  If not, see <http://www.gnu.org/licenses/>.
 
 	# --------------------------------------------------------
-	# $Id: email_api.php,v 1.121.10.1 2007/03/06 05:54:14 vboctor Exp $
+	# $Id: email_api.php,v 1.139.2.3 2007-10-22 07:40:59 vboctor Exp $
 	# --------------------------------------------------------
 
 	$t_core_dir = dirname( __FILE__ ).DIRECTORY_SEPARATOR;
-	define( 'PHPMAILER_PATH', $t_core_dir . 'phpmailer' . DIRECTORY_SEPARATOR );
 
+	define( 'PHPMAILER_PATH', $t_core_dir . 'phpmailer' . DIRECTORY_SEPARATOR );
+	
 	require_once( $t_core_dir . 'current_user_api.php' );
 	require_once( $t_core_dir . 'bug_api.php' );
 	require_once( $t_core_dir . 'custom_field_api.php' );
 	require_once( $t_core_dir . 'string_api.php' );
 	require_once( $t_core_dir . 'history_api.php' );
+	require_once( $t_core_dir . 'email_queue_api.php' );
+	require_once( $t_core_dir . 'relationship_api.php' );
+	require_once( $t_core_dir . 'disposable' . DIRECTORY_SEPARATOR . 'disposable.php' );
 	require_once( PHPMAILER_PATH . 'class.phpmailer.php' );
 
 	# reusable object of class SMTP
@@ -26,6 +42,14 @@
 	# Email API
 	###########################################################################
 
+	# Use a simple perl regex for valid email addresses.  This is not a complete regex,
+	# as it does not cover quoted addresses or domain literals, but it is simple and
+	# covers the vast majority of all email addresses without being overly complex.
+	# Callers must surround this with appropriate delimiters with case insentive options.
+	function email_regex_simple() {
+		return "(([a-z0-9!#*+\/=?^_{|}~-]+(?:\.[a-z0-9!#*+\/=?^_{|}~-]+)*)" . 				# recipient
+			"\@((?:[a-z0-9](?:[a-z0-9-]*[a-z0-9])?\.)+[a-z0-9](?:[a-z0-9-]*[a-z0-9])?))";	# @domain
+	}
 
 	# --------------------
 	# Return a perl compatible regular expression that will
@@ -148,6 +172,21 @@
 			trigger_error( ERROR_EMAIL_INVALID, ERROR );
 		}
 	}
+
+	# --------------------
+	# Check if the email address is disposable
+	function email_is_disposable( $p_email ) {
+		return DisposableEmailChecker::is_disposable_email( $p_email ); 
+	}
+
+	# --------------------
+	# Check if the email address is disposable
+	function email_ensure_not_disposable( $p_email ) {
+		if ( email_is_disposable( $p_email ) ) {
+			trigger_error( ERROR_EMAIL_DISPOSABLE, ERROR );
+		}
+	}
+
 	# --------------------
 	# email_notify_flag
 	# Get the value associated with the specific action and flag.
@@ -178,14 +217,17 @@
 		if ( ON == email_notify_flag( $p_notify_type, 'reporter' ) ) {
 			$t_reporter_id = bug_get_field( $p_bug_id, 'reporter_id' );
 			$t_recipients[$t_reporter_id] = true;
-			log_event( LOG_EMAIL_RECIPIENT, "bug= $p_bug_id, add reporter=$t_reporter_id" );
+			log_event( LOG_EMAIL_RECIPIENT, "bug=$p_bug_id, add reporter=$t_reporter_id" );
 		}
 
 		# add Handler
 		if ( ON == email_notify_flag( $p_notify_type, 'handler' )) {
 			$t_handler_id = bug_get_field( $p_bug_id, 'handler_id' );
-			$t_recipients[$t_handler_id] = true;
-			log_event( LOG_EMAIL_RECIPIENT, "bug= $p_bug_id, add handler=$t_handler_id" );
+			
+			if ( $t_handler_id > 0 ) {
+				$t_recipients[$t_handler_id] = true;
+				log_event( LOG_EMAIL_RECIPIENT, "bug=$p_bug_id, add handler=$t_handler_id" );
+			}
 		}
 
 		$t_project_id = bug_get_field( $p_bug_id, 'project_id' );
@@ -202,7 +244,7 @@
 			for ( $i=0 ; $i < $count ; $i++ ) {
 				$t_user_id = db_result( $result, $i );
 				$t_recipients[$t_user_id] = true;
-			log_event( LOG_EMAIL_RECIPIENT, "bug= $p_bug_id, add monitor=$t_user_id" );
+				log_event( LOG_EMAIL_RECIPIENT, "bug=$p_bug_id, add monitor=$t_user_id" );
 			}
 		}
 
@@ -223,7 +265,7 @@
 			for( $i=0 ; $i < $count ; $i++ ) {
 				$t_user_id = db_result( $result, $i );
 				$t_recipients[$t_user_id] = true;
-				log_event( LOG_EMAIL_RECIPIENT, "bug= $p_bug_id, add note=$t_user_id" );
+				log_event( LOG_EMAIL_RECIPIENT, "bug=$p_bug_id, add note author=$t_user_id" );
 			}
 		}
 
@@ -236,7 +278,7 @@
 			if ( $t_user['access_level'] <= $t_threshold_max ) {
 				if ( !$t_bug_is_private || access_compare_level( $t_user['access_level'], config_get( 'private_bug_threshold' ) ) ) {
 					$t_recipients[$t_user['id']] = true;
-					log_event( LOG_EMAIL_RECIPIENT, "bug= $p_bug_id, add project=" . $t_user['id'] );
+					log_event( LOG_EMAIL_RECIPIENT, "bug=$p_bug_id, add project user=" . $t_user['id'] );
 				}
 			}
 		}
@@ -269,18 +311,17 @@
 		# Check whether users should receive the emails
 		# and put email address to $t_recipients[user_id]
 		foreach ( $t_recipients as $t_id => $t_ignore ) {
-
 			# Possibly eliminate the current user
 			if ( ( auth_get_current_user_id() == $t_id ) &&
 				 ( OFF == config_get( 'email_receive_own' ) ) ) {
-				log_event( LOG_EMAIL_RECIPIENT, "bug= $p_bug_id, drop $t_id (own)" );
+				log_event( LOG_EMAIL_RECIPIENT, "bug=$p_bug_id, drop $t_id (own)" );
 				continue;
 			}
 
 			# Eliminate users who don't exist anymore or who are disabled
 			if ( !user_exists( $t_id ) ||
 				 !user_is_enabled( $t_id ) ) {
-				log_event( LOG_EMAIL_RECIPIENT, "bug= $p_bug_id, drop $t_id (disabled)" );
+				log_event( LOG_EMAIL_RECIPIENT, "bug=$p_bug_id, drop $t_id (disabled)" );
 				continue;
 			}
 
@@ -288,7 +329,7 @@
 			if ( $t_pref_field ) {
 				$t_notify = user_pref_get_pref( $t_id, $t_pref_field );
 				if ( OFF == $t_notify ) {
-					log_event( LOG_EMAIL_RECIPIENT, "bug= $p_bug_id, drop $t_id (pref $t_pref_field off)" );
+					log_event( LOG_EMAIL_RECIPIENT, "bug=$p_bug_id, drop $t_id (pref $t_pref_field off)" );
 					continue;
 				} else {
 					# Users can define the severity of an issue before they are emailed for
@@ -298,7 +339,7 @@
 					$t_bug_severity       = bug_get_field( $p_bug_id, 'severity' );
 
 					if ( $t_bug_severity < $t_min_sev_notify ) {
-						log_event( LOG_EMAIL_RECIPIENT, "bug= $p_bug_id, drop $t_id (pref threshold)" );
+						log_event( LOG_EMAIL_RECIPIENT, "bug=$p_bug_id, drop $t_id (pref threshold)" );
 						continue;
 					}
 				}
@@ -307,7 +348,7 @@
 			# check that user can see bugnotes if the last update included a bugnote
 			if ( $t_bug_date == $t_bugnote_date ) {
 				if ( !access_has_bugnote_level( VIEWER, $t_bugnote_id, $t_id ) ) {
-						log_event( LOG_EMAIL_RECIPIENT, "bug= $p_bug_id, drop $t_id (access level)" );
+						log_event( LOG_EMAIL_RECIPIENT, "bug=$p_bug_id, drop $t_id (access level)" );
 					continue;
 				}
 			}
@@ -315,13 +356,14 @@
 			# Finally, let's get their emails, if they've set one
 			$t_email = user_get_email( $t_id );
 			if ( is_blank( $t_email ) ) {
-				log_event( LOG_EMAIL_RECIPIENT, "bug= $p_bug_id, drop $t_id (no email)" );
+				log_event( LOG_EMAIL_RECIPIENT, "bug=$p_bug_id, drop $t_id (no email)" );
 			} else {
 				# @@@ we could check the emails for validity again but I think
 				#   it would be too slow
 				$t_final_recipients[$t_id] = $t_email;
 			}
 		}
+
 		return $t_final_recipients;
 	}
 
@@ -347,14 +389,18 @@
 		$t_message = lang_get( 'new_account_greeting' ) . $t_username .
 						lang_get( 'new_account_greeting2' ) . " \n\n" .
 						string_get_confirm_hash_url( $p_user_id, $p_confirm_hash ) . " \n\n" .
-						lang_get( 'new_account_message' ) .
+						lang_get( 'new_account_message' ) . "\n\n" .
 						lang_get( 'new_account_do_not_reply' );
 
 		# Send signup email regardless of mail notification pref
 		# or else users won't be able to sign up
 		if( !is_blank( $t_email ) ) {
-			email_send( $t_email, $t_subject, $t_message );
+			email_store( $t_email, $t_subject, $t_message );
 			log_event( LOG_EMAIL, "signup=$t_email, hash=$p_confirm_hash, id=$p_user_id" );
+
+			if ( OFF == config_get( 'email_send_using_cronjob' ) ) {
+				email_send_all();
+			}
 		}
 
 #		lang_pop(); # see above
@@ -363,7 +409,6 @@
 	# --------------------
 	# Send confirm_hash url to user forgets the password
 	function email_send_confirm_hash_url( $p_user_id, $p_confirm_hash ) {
-
 		if ( ( OFF == config_get( 'send_reset_password' ) ) || ( OFF == config_get( 'enable_email_notification' ) ) ) {
 			return;
 		}
@@ -385,8 +430,12 @@
 		# Send password reset regardless of mail notification prefs
 		# or else users won't be able to receive their reset pws
 		if( !is_blank( $t_email ) ) {
-			email_send( $t_email, $t_subject, $t_message );
+			email_store( $t_email, $t_subject, $t_message );
 			log_event( LOG_EMAIL, "password_reset=$t_email" );
+
+			if ( OFF == config_get( 'email_send_using_cronjob' ) ) {
+				email_send_all();
+			}
 		}
 
 		lang_pop();
@@ -414,8 +463,12 @@
 						lang_get( 'new_account_do_not_reply' );
 
 			if( !is_blank( $t_recipient_email ) ) {
-				email_send( $t_recipient_email, $t_subject, $t_message );
+				email_store( $t_recipient_email, $t_subject, $t_message );
 				log_event( LOG_EMAIL, "new_account_notify=$t_recipient_email" );
+
+				if ( OFF == config_get( 'email_send_using_cronjob' ) ) {
+					email_send_all();
+				}
 			}
 
 			lang_pop();
@@ -429,6 +482,7 @@
 	# Return false if it were problems sending email
 	function email_generic( $p_bug_id, $p_notify_type, $p_message_id = null, $p_header_optional_params = null ) {
 		$t_ok = true;
+
 		if ( ON === config_get( 'enable_email_notification' ) ) {
 			ignore_user_abort( true );
 
@@ -452,6 +506,11 @@
 					lang_pop();
 				}
 			}
+
+			# Only trigger the draining of the email queue if cronjob is disabled and email notifications are enabled.
+			if ( OFF == config_get( 'email_send_using_cronjob' ) ) {
+				email_send_all();
+			}
 		}
 
 		return $t_ok;
@@ -463,26 +522,11 @@
 	function email_relationship_added( $p_bug_id, $p_related_bug_id, $p_rel_type ) {
 		$t_opt = array();
 		$t_opt[] = bug_format_id( $p_related_bug_id );
-		switch ( $p_rel_type ) {
-			case BUG_BLOCKS:
-				email_generic( $p_bug_id, 'relation', 'email_notification_title_for_action_blocks_relationship_added', $t_opt );
-				break;
-			case BUG_DEPENDANT:
-				email_generic( $p_bug_id, 'relation', 'email_notification_title_for_action_dependant_on_relationship_added', $t_opt );
-				break;
-			case BUG_HAS_DUPLICATE:
-				email_generic( $p_bug_id, 'relation', 'email_notification_title_for_action_has_duplicate_relationship_added', $t_opt );
-				break;
-			case BUG_DUPLICATE:
-				email_generic( $p_bug_id, 'relation', 'email_notification_title_for_action_duplicate_of_relationship_added', $t_opt );
-				break;
-			case BUG_RELATED:
-				email_generic( $p_bug_id, 'relation', 'email_notification_title_for_action_related_to_relationship_added', $t_opt );
-				break;
-			default:
-				trigger_error( ERROR_RELATIONSHIP_NOT_FOUND, ERROR );
-				break;
-			}
+		global $g_relationships;
+		if ( !isset( $g_relationships[ $p_rel_type ] ) ) {
+			trigger_error( ERROR_RELATIONSHIP_NOT_FOUND, ERROR );
+		}
+		email_generic( $p_bug_id, 'relation', $g_relationships[ $p_rel_type ][ '#notify_added' ], $t_opt );
 	}
 
 	# --------------------
@@ -491,26 +535,11 @@
 	function email_relationship_deleted( $p_bug_id, $p_related_bug_id, $p_rel_type ) {
 		$t_opt = array();
 		$t_opt[] = bug_format_id( $p_related_bug_id );
-		switch ( $p_rel_type ) {
-			case BUG_BLOCKS:
-				email_generic( $p_bug_id, 'relation', 'email_notification_title_for_action_blocks_relationship_deleted', $t_opt );
-				break;
-			case BUG_DEPENDANT:
-				email_generic( $p_bug_id, 'relation', 'email_notification_title_for_action_dependant_on_relationship_deleted', $t_opt );
-				break;
-			case BUG_HAS_DUPLICATE:
-				email_generic( $p_bug_id, 'relation', 'email_notification_title_for_action_has_duplicate_relationship_deleted', $t_opt );
-				break;
-			case BUG_DUPLICATE:
-				email_generic( $p_bug_id, 'relation', 'email_notification_title_for_action_duplicate_of_relationship_deleted', $t_opt );
-				break;
-			case BUG_RELATED:
-				email_generic( $p_bug_id, 'relation', 'email_notification_title_for_action_related_to_relationship_deleted', $t_opt );
-				break;
-			default:
-				trigger_error( ERROR_RELATIONSHIP_NOT_FOUND, ERROR );
-				break;
-			}
+		global $g_relationships;
+		if ( !isset( $g_relationships[ $p_rel_type ] ) ) {
+			trigger_error( ERROR_RELATIONSHIP_NOT_FOUND, ERROR );
+		}
+		email_generic( $p_bug_id, 'relation', $g_relationships[ $p_rel_type ][ '#notify_deleted' ], $t_opt );
 	}
 
 	# --------------------
@@ -531,7 +560,6 @@
 	# send notices to all the handlers of the parent bugs still open when a child bug is resolved/closed
 	# MASC RELATIONSHIP
 	function email_relationship_child_resolved_closed( $p_bug_id, $p_message_id ) {
-
 		# retrieve all the relationships in which the bug is the destination bug
 		$t_relationship = relationship_get_all_dest( $p_bug_id );
 		$t_relationship_count = count( $t_relationship );
@@ -608,13 +636,7 @@
 		email_generic( $p_bug_id, 'deleted', 'email_notification_title_for_action_bug_deleted' );
 	}
 	# --------------------
-	# this function sends the actual email
-	# if $p_exit_on_error == true (default) - calls exit() on errors, else - returns true on success and false on errors
-	# @@@@ (thraxisp) $p_header doesn't work as expected, it adds a list of names to the bcc list, rather than headers
-	#         this is ok for now as nothing uses it
-	function email_send( $p_recipient, $p_subject, $p_message, $p_header='', $p_category='', $p_exit_on_error=true ) {
-		global $g_phpMailer_smtp;
-
+	function email_store( $p_recipient, $p_subject, $p_message, $p_headers = null ) {
 		$t_recipient = trim( $p_recipient );
 		$t_subject   = string_email( trim( $p_subject ) );
 		$t_message   = string_email_links( trim( $p_message ) );
@@ -626,25 +648,91 @@
 			return;
 		}
 
-		# for debugging only
-		#PRINT $t_recipient.'<br />'.$t_subject.'<br />'.$t_message.'<br />'.$t_headers;
-		#exit;
-		#PRINT '<br />xxxRecipient ='.$t_recipient.'<br />';
-		#PRINT 'Headers ='.nl2br($t_headers).'<br />';
-		#PRINT $t_subject.'<br />';
-		#PRINT nl2br($t_message).'<br />';
-		#exit;
+		$t_email_data = new EmailData;
 
-		$t_debug_email = config_get('debug_email');
+		$t_email_data->email = $t_recipient;
+		$t_email_data->subject = $t_subject;
+		$t_email_data->body = $t_message;
+		$t_email_data->metadata = array();
+		$t_email_data->metadata['headers'] = $p_headers === null ? array() : $p_headers;
+		$t_email_data->metadata['priority'] = config_get( 'mail_priority' );               # Urgent = 1, Not Urgent = 5, Disable = 0
+		$t_email_data->metadata['charset'] =  lang_get( 'charset', lang_get_current() );
+
+        $t_hostname = '';
+        $t_server = isset( $_SERVER ) ? $_SERVER : $HTTP_SERVER_VARS;
+        if ( isset( $t_server['SERVER_NAME'] ) ) {
+            $t_hostname = $t_server['SERVER_NAME'];
+        } else {
+            $t_address = explode( '@', config_get( 'from_email' ) );
+            if ( isset( $t_address[1] ) ) {
+                $t_hostname = $t_address[1];
+            }
+        }
+        $t_email_data->metadata['hostname'] = $t_hostname;
+
+		$t_email_id = email_queue_add( $t_email_data );
+		
+		return $t_email_id; 
+	}
+
+	# --------------------
+	# This function sends all the emails that are stored in the queue.  If a failure occurs, then the
+	# function exists.  This function will be called after storing emails in case of synchronous
+	# emails, or will be called from a cronjob in case of asynchronous emails.
+	# @@@ In case of synchronous email sending, we may get a race condition where two requests send the same email.
+	function email_send_all() {
+		$t_ids = email_queue_get_ids();
+
+		$t_emails_recipients_failed = array();
+		$t_start = microtime_float();
+		foreach ( $t_ids as $t_id ) {
+			$t_email_data = email_queue_get( $t_id );
+
+			# check if email was not found.  This can happen if another request picks up the email first and sends it.
+			if ( $t_email_data === false ) {
+				continue;
+			}
+
+			# if unable to place the email in the email server queue, then the connection to the server is down,
+			# and hence no point to continue trying with the rest of the emails.
+			if ( !email_send( $t_email_data ) ) {
+				if ( microtime_float() - $t_start > 5)
+					break;
+				else 
+					continue;
+			}
+		}
+	}
+
+	# --------------------
+	# This function sends an email message based on the supplied email data.
+	function email_send( $p_email_data ) {
+		global $g_phpMailer_smtp;
+
+		$t_email_data = $p_email_data;
+
+		$t_recipient = trim( $t_email_data->email );
+		$t_subject   = string_email( trim( $t_email_data->subject ) );
+		$t_message   = string_email_links( trim( $t_email_data->body ) );
+
+		$t_debug_email = config_get( 'debug_email' );
 
 		# Visit http://phpmailer.sourceforge.net
 		# if you have problems with phpMailer
 
 		$mail = new PHPMailer;
-
 		$mail->PluginDir = PHPMAILER_PATH;
+		
+		if ( isset( $t_email_data->metadata['hostname'] ) ) {
+			$mail->Hostname = $t_email_data->metadata['hostname'];
+		}
+
 		# @@@ should this be the current language (for the recipient) or the default one (for the user running the command) (thraxisp)
-		$mail->SetLanguage( lang_get( 'phpmailer_language', lang_get_current() ), PHPMAILER_PATH . 'language' . DIRECTORY_SEPARATOR );
+		$t_lang = config_get( 'default_language' );
+		if ( 'auto' == $t_lang ) {
+			$t_lang = config_get( 'fallback_language');
+		}
+		$mail->SetLanguage( lang_get( 'phpmailer_language', $t_lang ), PHPMAILER_PATH . 'language' . DIRECTORY_SEPARATOR );
 
 		# Select the method to send mail
 		switch ( config_get( 'phpMailer_method' ) ) {
@@ -659,6 +747,7 @@
 						# SMTP collection is always kept alive
 						#
 						$mail->SMTPKeepAlive = true;
+
 						# @@@ yarick123: It is said in phpMailer comments, that phpMailer::smtp has private access.
 						# but there is no common method to reset PHPMailer object, so
 						# I see the smallest evel - to initialize only one 'private'
@@ -672,76 +761,46 @@
 					}
 					break;
 		}
-		$mail->IsHTML(false);              # set email format to plain text
+
+		$mail->IsHTML( false );              # set email format to plain text
 		$mail->WordWrap = 80;              # set word wrap to 50 characters
-		$mail->Priority = config_get( 'mail_priority' );               # Urgent = 1, Not Urgent = 5, Disable = 0
-		$mail->CharSet = lang_get( 'charset', lang_get_current() );
+		$mail->Priority = $t_email_data->metadata['priority'];  # Urgent = 1, Not Urgent = 5, Disable = 0
+		$mail->CharSet = $t_email_data->metadata['charset'];
 		$mail->Host     = config_get( 'smtp_host' );
 		$mail->From     = config_get( 'from_email' );
-		$mail->Sender   = config_get( 'return_path_email' );
-		$mail->FromName = '';
+		$mail->Sender   = escapeshellcmd( config_get( 'return_path_email' ) );
+		$mail->FromName = config_get( 'from_name');
+
+
 		if ( !is_blank( config_get( 'smtp_username' ) ) ) {     # Use SMTP Authentication
 			$mail->SMTPAuth = true;
 			$mail->Username = config_get( 'smtp_username' );
 			$mail->Password = config_get( 'smtp_password' );
 		}
 
-		$t_debug_to = '';
-		# add to the Recipient list
-		$t_recipient_list = split(',', $t_recipient);
-		while ( list( , $t_recipient ) = each( $t_recipient_list ) ) {
-			if ( !is_blank( $t_recipient ) ) {
-				if ( OFF === $t_debug_email ) {
-					$mail->AddAddress( $t_recipient, '' );
-				} else {
-					$t_debug_to .= !is_blank( $t_debug_to ) ? ', ' : '';
-					$t_debug_to .= $t_recipient;
-				}
-			}
-		}
-
-		# add to the BCC list
-		$t_debug_bcc = '';
-		$t_bcc_list = split(',', $p_header);
-		while(list(, $t_bcc) = each($t_bcc_list)) {
-			if ( !is_blank( $t_bcc ) ) {
-				if ( OFF === $t_debug_email ) {
-					$mail->AddBCC( $t_bcc, '' );
-				} else {
-					$t_debug_bcc .= !is_blank( $t_debug_bcc ) ? ', ' : '';
-					$t_debug_bcc .= $t_bcc;
-				}
-			}
-		}
-
 		if ( OFF !== $t_debug_email ) {
-			$t_message = "\n" . $t_message;
-
-			if ( !is_blank( $t_debug_bcc ) ) {
-				$t_message = 'Bcc: ' . $t_debug_bcc . "\n" . $t_message;
-			}
-
-			if ( !is_blank( $t_debug_to ) ) {
-				$t_message = 'To: '. $t_debug_to . "\n" . $t_message;
-			}
-
+			$t_message = 'To: '. $t_recipient . "\n\n" . $t_message;
 			$mail->AddAddress( $t_debug_email, '' );
+		} else {
+			$mail->AddAddress( $t_recipient, '' );
 		}
 
 		$mail->Subject = $t_subject;
-		$mail->Body    = make_lf_crlf( "\n".$t_message );
+		$mail->Body    = make_lf_crlf( "\n" . $t_message );
 
-		if ( EMAIL_CATEGORY_PROJECT_CATEGORY == config_get( 'email_set_category' ) )  {
-			$mail->AddCustomHeader( "Keywords: $p_category" );
+		if ( isset( $t_email_data->metadata['headers'] ) && is_array( $t_email_data->metadata['headers'] ) ) {
+			foreach ( $t_email_data->metadata['headers'] as $t_key => $t_value ) {
+				$mail->AddCustomHeader( "$t_key: $t_value" );
+			}
 		}
 
 		if ( !$mail->Send() ) {
-			PRINT "PROBLEMS SENDING MAIL TO: $p_recipient<br />";
-			PRINT 'Mailer Error: '.$mail->ErrorInfo.'<br />';
-			if ( $p_exit_on_error )  {
-				exit;
-			} else {
-				return false;
+			$t_success = false;
+		} else {
+			$t_success = true;
+
+			if ( $t_email_data->email_id > 0 ) {
+				email_queue_delete( $t_email_data->email_id );
 			}
 		}
 
@@ -753,7 +812,7 @@
 			$g_phpMailer_smtp = $mail->smtp;
 		}
 
-		return true;
+		return $t_success;
 	}
 
 	# --------------------
@@ -839,11 +898,16 @@
 							" \n\n$p_message";
 
 			if( ON == config_get( 'enable_email_notification' ) ) {
-				email_send( $t_email, $t_subject, $t_contents );
+				email_store( $t_email, $t_subject, $t_contents );
 			}
 
 			lang_pop();
 		}
+
+		if ( OFF == config_get( 'email_send_using_cronjob' ) ) {
+			email_send_all();
+		}
+
 		return $result;
 	}
 
@@ -879,9 +943,19 @@
 
 		$t_message .= email_format_bug_message(  $p_visible_bug_data );
 
+		# build headers
+		$t_bug_id = $p_visible_bug_data['email_bug'];
+		$t_message_md5 = md5( $t_bug_id . $p_visible_bug_data['email_date_submitted'] );
+		$t_mail_headers = array( 'keywords' => $p_visible_bug_data['set_category'] );
+		if ( $p_message_id == 'email_notification_title_for_action_bug_submitted' ) {
+			$t_mail_headers['Message-ID'] = "<{$t_message_md5}>";
+		} else {
+			$t_mail_headers['In-Reply-To'] = "<{$t_message_md5}>";
+		}
+
 		# send mail
 		# PRINT '<br />email_bug_info::Sending email to :'.$t_user_email;
-		$t_ok = email_send( $t_user_email, $t_subject, $t_message, '', $p_visible_bug_data['set_category'], false );
+		$t_ok = email_store( $t_user_email, $t_subject, $t_message, $t_mail_headers );
 
 		return $t_ok;
 	}
@@ -924,6 +998,7 @@
 		$t_message .= email_format_attribute( $p_visible_bug_data, 'email_severity' );
 		$t_message .= email_format_attribute( $p_visible_bug_data, 'email_priority' );
 		$t_message .= email_format_attribute( $p_visible_bug_data, 'email_status' );
+		$t_message .= email_format_attribute( $p_visible_bug_data, 'email_target_version' );
 
 		# custom fields formatting
 		foreach( $p_visible_bug_data['custom_fields'] as $t_custom_field_name => $t_custom_field_data ) {
@@ -977,7 +1052,33 @@
 		# format bugnotes
 		foreach ( $p_visible_bug_data['bugnotes'] as $t_bugnote ) {
 			$t_last_modified = date( $t_normal_date_format, $t_bugnote->last_modified );
-			$t_string = ' '. user_get_name( $t_bugnote->reporter_id ) . ' - ' . $t_last_modified . ' ';
+
+			$t_formatted_bugnote_id = bugnote_format_id( $t_bugnote->id );
+			$t_bugnote_link = string_process_bugnote_link ( config_get( 'bugnote_link_tag' ) . $t_bugnote->id, false, false, true );
+
+			$t_time_tracking = '';
+
+			# the bugnote objects array is retrieved from bugnote_get_all_visible_bugnotes which already checks for
+			# time_tracking_view_threshold.  If user does not have view permission the value is set to 0.
+			if ( $t_bugnote->time_tracking > 0 ) {
+				$t_time_tracking_minutes = bugnote_get_field ( $t_bugnote->id, 'time_tracking' );
+				if ( $t_time_tracking_minutes > 0 ) {
+					$t_time_tracking = ' ' . lang_get( 'time_tracking' ) . ' ' . db_minutes_to_hhmm( $t_time_tracking_minutes ) . "\n";
+				}
+			}
+
+			if ( user_exists( $t_bugnote->reporter_id ) ) {
+				$t_access_level = access_get_project_level( null,  $t_bugnote->reporter_id );
+				$t_access_level_string = ' (' . get_enum_element( 'access_levels', $t_access_level ) . ') - '; 
+			} else {
+				$t_access_level_string = '';
+			}
+
+			$t_string = ' (' . $t_formatted_bugnote_id . ') ' . 
+				user_get_name( $t_bugnote->reporter_id ) .
+				$t_access_level_string .
+				$t_last_modified . "\n" .
+				$t_time_tracking . ' ' . $t_bugnote_link;
 
 			$t_message .= $t_email_separator2 . " \n";
 			$t_message .= $t_string . " \n";
@@ -988,7 +1089,7 @@
 		# format history
 		if ( array_key_exists( 'history', $p_visible_bug_data ) ) {
 			$t_message .=	lang_get( 'bug_history' ) . " \n";
-			$t_message .=	str_pad( lang_get( 'date_modified' ), 16 ) .
+			$t_message .=	str_pad( lang_get( 'date_modified' ), 17 ) .
 							str_pad( lang_get( 'username' ), 15 ) .
 							str_pad( lang_get( 'field' ), 25 ) .
 							str_pad( lang_get( 'change' ), 20 ). " \n";
@@ -1001,7 +1102,7 @@
 															$t_raw_history_item['old_value'],
 															$t_raw_history_item['new_value'] );
 
-				$t_message .=	str_pad( date( $t_normal_date_format, $t_raw_history_item['date'] ), 16 ) .
+				$t_message .=	str_pad( date( $t_normal_date_format, $t_raw_history_item['date'] ), 17 ) .
 								str_pad( $t_raw_history_item['username'], 15 ) .
 								str_pad( $t_localized_item['note'], 25 ) .
 								str_pad( $t_localized_item['change'], 20 ) . "\n";
@@ -1067,6 +1168,10 @@
 		$t_bug_data['email_resolution'] = $row['resolution'];
 		$t_bug_data['email_fixed_in_version'] = $row['fixed_in_version'];
 
+		if ( !is_blank( $row['target_version'] ) && access_compare_level( $t_user_access_level, config_get( 'roadmap_view_threshold' ) ) ) {
+			$t_bug_data['email_target_version'] = $row['target_version'];
+		}
+
 		if ( DUPLICATE == $row['resolution'] ) {
 			$t_bug_data['email_duplicate'] = $row['duplicate_id'];
 		}
