@@ -1,12 +1,24 @@
 <?php
-	# Mantis - a php based bugtracking system
-	# Copyright (C) 2000 - 2002  Kenzaburo Ito - kenito@300baud.org
-	# Copyright (C) 2002 - 2004  Mantis Team   - mantisbt-dev@lists.sourceforge.net
-	# This program is distributed under the terms and conditions of the GPL
-	# See the README and LICENSE files for details
+# Mantis - a php based bugtracking system
+
+# Copyright (C) 2000 - 2002  Kenzaburo Ito - kenito@300baud.org
+# Copyright (C) 2002 - 2007  Mantis Team   - mantisbt-dev@lists.sourceforge.net
+
+# Mantis is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation, either version 2 of the License, or
+# (at your option) any later version.
+#
+# Mantis is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with Mantis.  If not, see <http://www.gnu.org/licenses/>.
 
 	# --------------------------------------------------------
-	# $Id: error_api.php,v 1.37 2004/11/30 13:02:57 vboctor Exp $
+	# $Id: error_api.php,v 1.53.2.1 2007-10-13 22:35:26 giallu Exp $
 	# --------------------------------------------------------
 
 	### Error API ###
@@ -34,20 +46,29 @@
 	function error_handler( $p_type, $p_error, $p_file, $p_line, $p_context ) {
 		global $g_error_parameters, $g_error_handled, $g_error_proceed_url;
 		global $g_lang_overrides;
+		global $g_error_send_page_header;
 
 		# check if errors were disabled with @ somewhere in this call chain
-		if ( 0 == error_reporting() ) {
+		# also suppress php 5 strict warnings
+		if ( 0 == error_reporting() || 2048 == $p_type ) {
 			return;
 		}
 
+		$t_lang_pushed = false;
+
 		# flush any language overrides to return to user's natural default
-		lang_push( config_get ( 'default_language' ) );
+		if ( function_exists( 'db_is_connected' ) ) {
+			if ( db_is_connected() ) {
+				lang_push( lang_get_default() );
+				$t_lang_pushed = true;
+			}
+		}
 
 		$t_short_file	= basename( $p_file );
 		$t_method_array = config_get( 'display_errors' );
 		if ( isset( $t_method_array[$p_type] ) ) {
 			$t_method = $t_method_array[$p_type];
-		}else{
+		} else {
 			$t_method		= 'none';
 		}
 
@@ -94,8 +115,15 @@
 				ob_end_clean();
 			}
 
-			html_page_top1();
-			html_page_top2();
+			# don't send the page header information if it has already been sent
+			if ( $g_error_send_page_header ) {			
+				html_page_top1();
+				if ( $p_error != ERROR_DB_QUERY_FAILED ) {
+					html_page_top2();
+				} else {
+					html_page_top2a();
+				}
+			}
 
 			PRINT '<br /><div align="center"><table class="width50" cellspacing="1">';
 			PRINT "<tr><td class=\"form-title\">$t_error_type</td></tr>";
@@ -127,7 +155,12 @@
 				PRINT '</div>';
 			}
 
-			html_page_bottom1();
+			if ( $p_error != ERROR_DB_QUERY_FAILED ) {
+				html_page_bottom1();
+			} else {
+				html_body_end();
+				html_end();
+			}
 			exit();
 		} else if ( 'inline' == $t_method ) {
 			PRINT "<p style=\"color:red\">$t_error_type: $t_error_description</p>";
@@ -135,7 +168,10 @@
 			# do nothing
 		}
 
-		lang_pop();
+		if ( $t_lang_pushed ) {
+			lang_pop();
+		}
+
 		$g_error_parameters = array();
 		$g_error_handled = true;
 		$g_error_proceed_url = null;
@@ -148,7 +184,7 @@
 		<center>
 			<table class="width75">
 				<tr>
-					<td>Full path: <?php PRINT htmlentities( $p_file ) ?></td>
+					<td>Full path: <?php PRINT string_html_entities( $p_file ) ?></td>
 				</tr>
 				<tr>
 					<td>Line: <?php PRINT $p_line ?></td>
@@ -166,12 +202,16 @@
 	# ---------------
 	# Print out the variable context given
 	function error_print_context( $p_context ) {
+		if( !is_array( $p_context ) ) {
+		  return;
+		}
+	
 		PRINT '<table class="width100"><tr><th>Variable</th><th>Value</th><th>Type</th></tr>';
 
 		# print normal variables
 		foreach ( $p_context as $t_var => $t_val ) {
 			if ( !is_array( $t_val ) && !is_object( $t_val ) ) {
-				$t_val = htmlentities( (string)$t_val );
+				$t_val = string_html_entities( (string)$t_val );
 				$t_type = gettype( $t_val );
 
 				# Mask Passwords
@@ -211,7 +251,7 @@
 
 			foreach ( $t_stack as $t_frame ) {
 				PRINT '<tr ' . helper_alternate_class() . '>';
-				PRINT '<td>' . htmlentities( $t_frame['file'] ) . '</td><td>' . $t_frame['line'] . '</td><td>' . $t_frame['function'] . '</td>';
+				PRINT '<td>' . string_html_entities( $t_frame['file'] ) . '</td><td>' . $t_frame['line'] . '</td><td>' . ( isset( $t_frame['function'] ) ? $t_frame['function'] : '???' ) . '</td>';
 
 				$t_args = array();
 				if ( isset( $t_frame['params'] ) ) {
@@ -220,10 +260,10 @@
 					}
 				}
 
-				PRINT '<td>( ' . htmlentities( implode( $t_args, ', ' ) ) . ' )</td></tr>';
+				PRINT '<td>( ' . string_html_entities( implode( $t_args, ', ' ) ) . ' )</td></tr>';
 			}
 			PRINT '</table></center>';
-		} else if ( php_version_at_least( '4.3' ) ) {
+		} else {
 			$t_stack = debug_backtrace();
 
 			array_shift( $t_stack ); #remove the call to this function from the stack trace
@@ -234,7 +274,7 @@
 
 			foreach ( $t_stack as $t_frame ) {
 				PRINT '<tr ' . helper_alternate_class() . '>';
-				PRINT '<td>' . htmlentities( $t_frame['file'] ) . '</td><td>' . $t_frame['line'] . '</td><td>' . $t_frame['function'] . '</td>';
+				PRINT '<td>' . string_html_entities( $t_frame['file'] ) . '</td><td>' . (isset( $t_frame['line'] ) ? $t_frame['line'] : '-') . '</td><td>' . $t_frame['function'] . '</td>';
 
 				$t_args = array();
 				if ( isset( $t_frame['args'] ) ) {
@@ -243,7 +283,7 @@
 					}
 				}
 
-				PRINT '<td>( ' . htmlentities( implode( $t_args, ', ' ) ) . ' )</td></tr>';
+				PRINT '<td>( ' . string_html_entities( implode( $t_args, ', ' ) ) . ' )</td></tr>';
 			}
 
 			PRINT '</table></center>';
@@ -302,7 +342,7 @@
 
 		$t_error = $MANTIS_ERROR[$p_error];
 
-		return call_user_func_array( 'sprintf', array_merge( array( $t_error ), $g_error_parameters, $t_padding ) );
+		return string_html_specialchars( call_user_func_array( 'sprintf', array_merge( array( $t_error ), $g_error_parameters, $t_padding ) ) );
 	}
 
 	# ---------------
@@ -334,4 +374,4 @@
 
 		$g_error_proceed_url = $p_url;
 	}
-?>
\ No newline at end of file
+?>
