@@ -47,6 +47,16 @@
 		return $t_result;
 	}
 	# -----------------
+	# test to see if a gpc is set
+	function gpc_isset( $p_var_name ) {
+		if ( isset( $_POST[$p_var_name] ) ) {
+			return true;
+		} else if ( isset( $_GET[$p_var_name] ) ) {
+			return true;
+		}
+		return false;
+	}
+	# -----------------
 	# Retrieve a string GPC variable. Uses gpc_get().
 	#  If you pass in *no* default, an error will be triggered if
 	#  the variable does not exist
@@ -107,6 +117,24 @@
 	# Custom Field Functions
 	#===================================
 
+	# ------------------
+	# see if a custom field variable is set.  Uses gpc_isset().
+	function gpc_isset_custom_field( $p_var_name, $p_custom_field_type ) {
+		switch ($p_custom_field_type ) {
+			case CUSTOM_FIELD_TYPE_DATE:
+				// date field is three dropdowns that default to 0
+				// Dropdowns are always present, so check if they are set
+				return gpc_isset( "custom_field_" . $p_var_name . "_day" ) &&
+					gpc_get_int( "custom_field_" . $p_var_name . "_day", 0 ) != 0 &&
+					gpc_isset( "custom_field_" . $p_var_name . "_month" ) &&
+					gpc_get_int( "custom_field_" . $p_var_name . "_month", 0 ) != 0 &&
+					gpc_isset( "custom_field_" . $p_var_name . "_year" ) &&
+					gpc_get_int( "custom_field_" . $p_var_name . "_year", 0 ) != 0 ;
+			default:
+				return gpc_isset( "custom_field_" . $p_var_name);
+		}
+	}
+
 	# ------------------
 	# Retrieve a custom field variable.  Uses gpc_get().
 	#  If you pass in *no* default, an error will be triggered if
@@ -115,8 +143,12 @@
 		switch ($p_custom_field_type ) {
 			case CUSTOM_FIELD_TYPE_MULTILIST:
 			case CUSTOM_FIELD_TYPE_CHECKBOX:
+			    // ensure that the default is an array, if it is set
+			    if ( ($p_default !== NULL) && (!is_array($p_default)) ) {
+			        $p_default = array( $p_default );
+			    }
 				$t_values = gpc_get_string_array( $p_var_name, $p_default );
-				if( null !== $t_values && '' != $t_values ) {
+				if( is_array( $t_values ) ) {
 					return implode( '|', $t_values );
 				} else {
 					return '';
