@@ -307,6 +307,18 @@
 			case 'last_updated':
 				$t_field_localized = lang_get( 'last_update' );
 				break;
+			case 'os':
+				$t_field_localized = lang_get( 'os' );
+				break;
+			case 'os_build':
+				$t_field_localized = lang_get( 'os_version' );
+				break;
+			case 'build':
+				$t_field_localized = lang_get( 'build' );
+				break;
+			case 'platform':
+				$t_field_localized = lang_get( 'platform' );
+				break;
 			case 'summary':
 				$t_field_localized = lang_get( 'summary' );
 				break;
