@@ -415,7 +415,7 @@
 			echo "\t", '<span class="timer"><a href="http://www.mantisbt.org/" title="Free Web Based Bug Tracker">Mantis ', MANTIS_VERSION, '</a>',
 					'[<a href="http://www.mantisbt.org/"  title="Free Web Based Bug Tracker" target="_blank">^</a>]</span>', "\n";
 		}
-		echo "\t", '<address>Copyright &copy; 2000 - 2008 Mantis Group</address>', "\n";
+		echo "\t", '<address>Copyright &copy; 2000 - 2009 Mantis Group</address>', "\n";
 
 		# only display webmaster email is current user is not the anonymous user
 		if ( ! is_page_name( 'login_page.php' ) && !current_user_is_anonymous() ) {
@@ -590,7 +590,7 @@
 				# Add custom options
 				$t_custom_options = prepare_custom_menu_options( 'main_menu_custom_options' );
 				$t_menu_options = array_merge( $t_menu_options, $t_custom_options );
-				if ( config_get('time_tracking_enabled') && config_get('time_tracking_with_billing') )
+				if ( config_get('time_tracking_enabled') && config_get('time_tracking_with_billing') && access_has_global_level( config_get( 'time_tracking_reporting_threshold' ) ) )
 					$t_menu_options[] = '<a href="billing_page.php">' . lang_get( 'time_tracking_billing_link' ) . '</a>';
 
 				# Logout (no if anonymously logged in)
@@ -1180,12 +1180,12 @@
 			echo '<td class="center">';
 			html_button_bug_assign_to( $p_bug_id );
 			echo '</td>';
-		}
 
-		# Change State button
-		echo '<td class="center">';
-		html_button_bug_change_status( $p_bug_id );
-		echo '</td>';
+			# Change State button
+			echo '<td class="center">';
+			html_button_bug_change_status( $p_bug_id );
+			echo '</td>';
+		}
 
 		# MONITOR/UNMONITOR button
 		echo '<td class="center">';
@@ -1217,12 +1217,12 @@
 			echo '<td class="center">';
 			html_button_bug_move( $p_bug_id );
 			echo '</td>';
-		}
 
-		# DELETE button
-		echo '<td class="center">';
-		html_button_bug_delete( $p_bug_id );
-		echo '</td>';
+			# DELETE button
+			echo '<td class="center">';
+			html_button_bug_delete( $p_bug_id );
+			echo '</td>';
+		}
 
 		helper_call_custom_function( 'print_bug_view_page_custom_buttons', array( $p_bug_id ) );
 
