@@ -1,12 +1,24 @@
 <?php
-	# Mantis - a php based bugtracking system
-	# Copyright (C) 2000 - 2002  Kenzaburo Ito - kenito@300baud.org
-	# Copyright (C) 2002 - 2004  Mantis Team   - mantisbt-dev@lists.sourceforge.net
-	# This program is distributed under the terms and conditions of the GPL
-	# See the README and LICENSE files for details
+# Mantis - a php based bugtracking system
+
+# Copyright (C) 2000 - 2002  Kenzaburo Ito - kenito@300baud.org
+# Copyright (C) 2002 - 2007  Mantis Team   - mantisbt-dev@lists.sourceforge.net
+
+# Mantis is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation, either version 2 of the License, or
+# (at your option) any later version.
+#
+# Mantis is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with Mantis.  If not, see <http://www.gnu.org/licenses/>.
 
 	# --------------------------------------------------------
-	# $Id: obsolete.php,v 1.29 2004/10/13 15:25:15 thraxisp Exp $
+	# $Id: obsolete.php,v 1.32.2.2 2007-10-16 22:15:41 giallu Exp $
 	# --------------------------------------------------------
 
 	### Obsolete API ###
@@ -86,16 +98,26 @@
 	config_obsolete( 'summary_pad', '' );
 
 	config_obsolete( 'show_project_in_title', '' );
-	
+
 # removed in 0.19
 	config_obsolete( 'hide_closed_default', 'hide_status_default' );
 
 	config_obsolete( 'close_bug_threshold', 'set_status_threshold' );
-	
+
 	config_obsolete( 'status_pulldown_enum_mask_string', '' );
 	config_obsolete( 'to_email', '' );
 	config_obsolete( 'use_bcc', '' );
 
 #removed in 0.19.1
 	config_obsolete( 'port', 'hostname');
+
+# changes in 0.19.3
+	config_obsolete( 'relationship_graph_fontpath', 'system_font_folder' );
+
+# changes in 1.1.0rc1
+	config_obsolete( 'show_notices', 'display_errors' );
+	config_obsolete( 'show_warnings', 'display_errors' );
+
+# changes in 1.1.0rc2
+	config_obsolete( 'wait_time', 'default_redirect_delay' );
 ?>
