@@ -304,7 +304,7 @@
 		?>
 		<input type="hidden" id="tag_separator" value="<?php echo config_get( 'tag_separator' ) ?>" />
 		<input type="text" name="tag_string" id="tag_string" size="40" value="<?php echo string_attribute( $p_string ) ?>" />
-		<select <?php echo helper_get_tab_index() ?> name="tag_select" id="tag_select">
+		<select <?php echo helper_get_tab_index() ?> name="tag_select" id="tag_select" onchange="tag_string_append( this.options[ this.selectedIndex ].text );">
 			<?php print_tag_option_list( $p_bug_id ); ?>
 		</select>
 		<?php
@@ -334,7 +334,7 @@
 
 		echo '<option value="0">',lang_get( 'tag_existing' ),'</option>';
 		while ( $row = db_fetch_array( $result ) ) {
-			echo '<option value="',$row['id'],'" onclick="tag_string_append(\'',$row['name'],'\')">',$row['name'],'</option>';
+			echo '<option value="',$row['id'],'">',$row['name'],'</option>';
 		}
 	}
 
@@ -829,11 +829,17 @@
 			echo '<option value=""></option>';
 		}
 
+		$t_listed = array();
+
 		foreach( $versions as $version ) {
 			$t_version = string_attribute( $version['version'] );
-			echo "<option value=\"$t_version\"";
-			check_selected( $p_version, $t_version );
-			echo '>', string_shorten( $t_version ), '</option>';
+
+			if ( !in_array( $t_version, $t_listed ) ) {
+				$t_listed[] = $t_version;
+				echo "<option value=\"$t_version\"";
+				check_selected( $p_version, $t_version );
+				echo '>', string_shorten( $t_version ), '</option>';
+			}
 		}
 	}
 	# --------------------
@@ -912,7 +918,7 @@
 
 		for ( $i = 0; $i < $t_enum_count; $i++ ) {
 			$t_elem  = explode_enum_arr( $t_arr[$i] );
-			if ( ( $p_user_auth >= access_get_status_threshold( $t_elem[0] ) ) &&
+			if ( ( access_compare_level( $p_user_auth, access_get_status_threshold( $t_elem[0] ) ) ) &&
 						( ! ( ( false == $p_show_current ) && ( $p_current_value == $t_elem[0] ) ) ) ) {
 				$t_enum_list[$t_elem[0]] = get_enum_element( 'status', $t_elem[0] );
 			}
@@ -920,7 +926,8 @@
 		if ( true == $p_show_current ) {
 				$t_enum_list[$p_current_value] = get_enum_element( 'status', $p_current_value );
 			}
-		if ( ( true == $p_add_close ) && ( $p_current_value >= config_get( 'bug_resolved_status_threshold' ) ) ) {
+		if ( ( true == $p_add_close ) && 
+					( access_compare_level( $p_current_value, config_get( 'bug_resolved_status_threshold' ) ) ) ) {
 				$t_enum_list[CLOSED] = get_enum_element( 'status', CLOSED );
 			}
 		return $t_enum_list;
