@@ -1,12 +1,24 @@
 <?php
-	# Mantis - a php based bugtracking system
-	# Copyright (C) 2000 - 2002  Kenzaburo Ito - kenito@300baud.org
-	# Copyright (C) 2002 - 2004  Mantis Team   - mantisbt-dev@lists.sourceforge.net
-	# This program is distributed under the terms and conditions of the GPL
-	# See the README and LICENSE files for details
+# Mantis - a php based bugtracking system
+
+# Copyright (C) 2000 - 2002  Kenzaburo Ito - kenito@300baud.org
+# Copyright (C) 2002 - 2007  Mantis Team   - mantisbt-dev@lists.sourceforge.net
+
+# Mantis is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation, either version 2 of the License, or
+# (at your option) any later version.
+#
+# Mantis is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with Mantis.  If not, see <http://www.gnu.org/licenses/>.
 
 	# --------------------------------------------------------
-	# $Id: relationship_graph_api.php,v 1.4 2005/04/22 21:34:04 prichards Exp $
+	# $Id: relationship_graph_api.php,v 1.6.2.1 2007-10-13 22:35:42 giallu Exp $
 	# --------------------------------------------------------
 
 	### Relationship Graph API ###
@@ -133,6 +145,7 @@
 		) );
 
 		# Add all issue nodes and edges to the graph.
+		ksort( $v_bug_list );
 		foreach ( $v_bug_list as $t_id => $t_bug ) {
 			$t_id_string	= bug_format_id( $t_id );
 
@@ -157,32 +170,12 @@
 
 					$t_related_id	= bug_format_id( $t_dst );
 
-					switch ( $t_relation ) {
-						case BUG_DUPLICATE:
-							$t_edge_style = array (
-								'style' => 'dashed',
-								'color' => '#808080'
-							);
-							break;
-
-						case BUG_DEPENDANT:
-							$t_edge_style = array (
-								'color' => '#C00000',
-								'dir' => 'back'
-							);
-							break;
-
-						case BUG_BLOCKS:
-							$t_edge_style = array (
-								'color' => '#C00000',
-								'dir' => 'forward'
-							);
-							break;
-
-						default:
-							$t_edge_style = array ( );
-							break;
-					}
+          global $g_relationships;
+          if ( isset( $g_relationships[ $t_relation ] ) && isset( $g_relationships[ $t_relation ][ '#edge_style' ] ) ) {
+            $t_edge_style = $g_relationships[ $t_relation ][ '#edge_style' ];
+          } else {
+            $t_edge_style = array ( );
+          }
 
 					$t_graph->add_edge( $t_id_string, $t_related_id, $t_edge_style );
 				}
