@@ -1,7 +1,7 @@
 <?php
 # Mantis - a php based bugtracking system
 
-# Copyright (C) 2008 - 2008  Mantis Team   - mantisbt-dev@lists.sourceforge.net
+# Copyright (C) 2008 - 2009  Mantis Team   - mantisbt-dev@lists.sourceforge.net
 
 # Mantis is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -48,20 +48,36 @@ $g_session = null;
  * to PHP's session.* settings in 'php.ini'.
  */
 class MantisPHPSession extends MantisSession {
-	function __construct() {
+	function __construct( $p_session_id=null ) {
+		$this->key = config_get_global( 'session_key' );
+
+		# Save session information where specified or with PHP's default
 		$t_session_save_path = config_get_global( 'session_save_path' );
 		if ( $t_session_save_path ) {
 			session_save_path( $t_session_save_path );
 		}
 
+		# Handle session cookie and caching
 		session_cache_limiter( 'private_no_expire' );
 		if ( isset( $_SERVER['HTTPS'] ) && ( strtolower( $_SERVER['HTTPS'] ) != 'off' ) ) {
 			session_set_cookie_params( 0, config_get( 'cookie_path' ), config_get( 'cookie_domain' ), true );
 		} else {
 			session_set_cookie_params( 0, config_get( 'cookie_path' ), config_get( 'cookie_domain' ), false );
 		}
+
+		# Handle existent session ID
+		if ( !is_null( $p_session_id ) ) {
+			session_id( $p_session_id );
+		}
+
+		# Initialize the session
 		session_start();
 		$this->id = session_id();
+
+		# Initialize the keyed session store
+		if ( !isset( $_SESSION[ $this->key ] ) ) {
+			$_SESSION[ $this->key ] = array();
+		}
 	}
 
 	# Chain the PHP4 class constructor
@@ -70,8 +86,8 @@ class MantisPHPSession extends MantisSession {
 	}
 
 	function get( $p_name, $p_default=null ) {
-		if ( isset( $_SESSION[ $p_name ] ) ) {
-			return unserialize( $_SESSION[ $p_name ] );
+		if ( isset( $_SESSION[ $this->key ][ $p_name ] ) ) {
+			return unserialize( $_SESSION[ $this->key ][ $p_name ] );
 		}
 
 		if ( func_num_args() > 1 ) {
@@ -83,11 +99,11 @@ class MantisPHPSession extends MantisSession {
 	}
 
 	function set( $p_name, $p_value ) {
-		$_SESSION[ $p_name ] = serialize( $p_value );
+		$_SESSION[ $this->key ][ $p_name ] = serialize( $p_value );
 	}
 
 	function delete( $p_name ) {
-		unset( $_SESSION[ $p_name ] );
+		unset( $_SESSION[ $this->key ][ $p_name ] );
 	}
 
 	function destroy() {
@@ -95,20 +111,20 @@ class MantisPHPSession extends MantisSession {
 			gpc_set_cookie( session_name(), '', time() - 42000 );
 		}
 
-		unset( $_SESSION );
-		session_destroy();
+		unset( $_SESSION[ $this->key ] );
 	}
 }
 
 /**
  * Initialize the appropriate session handler.
+ * @param string Session ID
  */
-function session_init() {
+function session_init( $p_session_id=null ) {
 	global $g_session, $g_session_handler;
 
 	switch( strtolower( $g_session_handler ) ) {
 		case 'php':
-			$g_session = new MantisPHPSession();
+			$g_session = new MantisPHPSession( $p_session_id );
 			break;
 
 		case 'adodb':
@@ -119,6 +135,40 @@ function session_init() {
 			trigger_error( ERROR_SESSION_HANDLER_INVALID, ERROR );
 			break;
 	}
+
+	# Disable session validation for the time being
+	#session_validate( $g_session );
+}
+
+/**
+ * Validate the legitimacy of a session.
+ * Checks may include last-known IP address, or more.
+ * Triggers an error when the session is invalid.
+ * @param object Session object
+ */
+function session_validate( $p_session ) {
+	$t_user_ip = '';
+	if ( isset( $_SERVER['REMOTE_ADDR'] ) ) {
+		$t_user_ip = trim( $_SERVER['REMOTE_ADDR'] );
+	}
+
+	if ( is_null( $t_last_ip = $p_session->get( 'last_ip', null ) ) ) {
+		# First session usage
+		$p_session->set( 'last_ip', $t_user_ip );
+
+	} else {
+		# Check a continued session request
+		if ( $t_user_ip != $t_last_ip ) {
+			session_clean();
+
+			trigger_error( ERROR_SESSION_NOT_VALID, WARNING );
+
+			$t_url = config_get_global( 'path' ) . config_get_global( 'default_home_page' );
+			echo "\t<meta http-equiv=\"Refresh\" content=\"4;URL=$t_url\" />\n";
+
+			die();
+		}
+	}
 }
 
 /**
@@ -190,4 +240,11 @@ function session_clean() {
 
 
 ##### Initialize the session
-session_init();
+$t_session_id = gpc_get_string( 'session_id', '' );
+
+if ( empty( $t_session_id ) ) {
+	session_init();
+} else {
+	session_init( $t_session_id );
+}
+
