@@ -1,12 +1,24 @@
 <?php
-	# Mantis - a php based bugtracking system
-	# Copyright (C) 2000 - 2002  Kenzaburo Ito - kenito@300baud.org
-	# Copyright (C) 2002 - 2004  Mantis Team   - mantisbt-dev@lists.sourceforge.net
-	# This program is distributed under the terms and conditions of the GPL
-	# See the README and LICENSE files for details
+# Mantis - a php based bugtracking system
+
+# Copyright (C) 2000 - 2002  Kenzaburo Ito - kenito@300baud.org
+# Copyright (C) 2002 - 2007  Mantis Team   - mantisbt-dev@lists.sourceforge.net
+
+# Mantis is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation, either version 2 of the License, or
+# (at your option) any later version.
+#
+# Mantis is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with Mantis.  If not, see <http://www.gnu.org/licenses/>.
 
 	# --------------------------------------------------------
-	# $Id: history_inc.php,v 1.25 2004/10/16 00:22:39 vboctor Exp $
+	# $Id: history_inc.php,v 1.32.2.1 2007-10-13 22:33:15 giallu Exp $
 	# --------------------------------------------------------
 ?>
 <?php
@@ -16,7 +28,7 @@
 ?>
 <?php
 	$t_core_path = config_get( 'core_path' );
-	
+
 	require_once( $t_core_path.'history_api.php' );
 ?>
 
@@ -29,32 +41,16 @@
 
 <a name="history" id="history" /><br />
 
-<?php if ( ON == config_get( 'use_javascript' ) ) { ?>
-<div id="history_closed" style="display: none;">
-<table class="width100" cellspacing="0">
-<tr>
-	<td class="form-title" colspan="4">
-		<a href="" onClick="ToggleDiv( 'history', g_div_history ); return false;"
-		><img border="0" src="images/plus.png" alt="+" /></a>
-		<?php echo lang_get( 'bug_history' ) ?>
-	</td>
-</tr>
-</table>
-</div>
-<?php } ?>
-
-<div id="history_open">
 <?php
+	collapse_open( 'history' );
 	$t_history = history_get_events_array( $f_bug_id );
 ?>
 <table class="width100" cellspacing="0">
 <tr>
 	<td class="form-title" colspan="4">
-<?php if ( ON == config_get( 'use_javascript' ) ) { ?>
-		<a href="" onClick="ToggleDiv( 'history', g_div_history ); return false;"
-		><img border="0" src="images/minus.png" alt="-" /></a>
-<?php } ?>
-		<?php echo lang_get( 'bug_history' ) ?>
+<?php
+	collapse_icon( 'history' );
+	echo lang_get( 'bug_history' ) ?>
 	</td>
 </tr>
 <tr class="row-category-history">
@@ -85,7 +81,7 @@
 		<?php echo string_display( $t_item['note'] ) ?>
 	</td>
 	<td class="small-caption">
-		<?php echo string_display( $t_item['change'] ) ?>
+		<?php echo string_display_line_links( $t_item['change'] ) ?>
 	</td>
 </tr>
 <?php
@@ -93,9 +89,18 @@
 ?>
 </table>
 </div>
+<?php
+	collapse_closed( 'history' );
+?>
+<table class="width100" cellspacing="0">
+<tr>
+	<td class="form-title" colspan="4">
+	<?php	collapse_icon( 'history' );
+		echo lang_get( 'bug_history' ) ?>
+	</td>
+</tr>
+</table>
 
-<?php if ( ON == config_get( 'use_javascript' ) ) { ?>
-<script type="text/JavaScript">
-	SetDiv( "history", g_div_history );
-</script>
-<?php } ?>
+<?php
+	collapse_end( 'history' );
+?>
