@@ -1,22 +1,34 @@
 <?php
-	# Mantis - a php based bugtracking system
-	# Copyright (C) 2000 - 2002  Kenzaburo Ito - kenito@300baud.org
-	# Copyright (C) 2002 - 2004  Mantis Team   - mantisbt-dev@lists.sourceforge.net
-	# This program is distributed under the terms and conditions of the GPL
-	# See the README and LICENSE files for details
+# Mantis - a php based bugtracking system
+
+# Copyright (C) 2000 - 2002  Kenzaburo Ito - kenito@300baud.org
+# Copyright (C) 2002 - 2007  Mantis Team   - mantisbt-dev@lists.sourceforge.net
+
+# Mantis is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation, either version 2 of the License, or
+# (at your option) any later version.
+#
+# Mantis is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with Mantis.  If not, see <http://www.gnu.org/licenses/>.
 
 	# --------------------------------------------------------
-	# $Id: manage_user_page.php,v 1.59.8.1.2.1.4.1 2007/03/06 07:00:33 vboctor Exp $
+	# $Id: manage_user_page.php,v 1.64.2.1 2007-10-13 22:33:55 giallu Exp $
 	# --------------------------------------------------------
-?>
-<?php
+
 	require_once( 'core.php' );
 
 	$t_core_path = config_get( 'core_path' );
 
 	require_once( $t_core_path . 'icon_api.php' );
-?>
-<?php
+
+	auth_reauthenticate();
+
 	access_ensure_global_level( config_get( 'manage_user_threshold' ) );
 
 	$f_sort	= gpc_get_string( 'sort', 'username' );
@@ -115,7 +127,7 @@ for ($i=0;$i<$new_user_count;$i++) {
 <?php
 	$query = "SELECT *
 		FROM $t_user_table
-		WHERE login_count=0
+		WHERE ( login_count = 0 ) AND ( date_created = last_visit )
 		ORDER BY date_created DESC";
 	$result = db_query( $query );
 	$user_count = db_num_rows( $result );
@@ -208,7 +220,7 @@ for ($i=0;$i<$new_user_count;$i++) {
 		<?php echo lang_get( 'manage_accounts_title' ) ?> [<?php echo $user_count ?>]
 		<?php print_button( 'manage_user_create_page.php', lang_get( 'create_new_account_link' ) ) ?>
 	</td>
-	<td class="center" colspan="2">
+	<td class="center" colspan="3">
 		<form method="post" action="manage_user_page.php">
 		<input type="hidden" name="sort" value="<?php echo $c_sort ?>" />
 		<input type="hidden" name="dir" value="<?php echo $c_dir ?>" />
