@@ -1,12 +1,24 @@
 <?php
-	# Mantis - a php based bugtracking system
-	# Copyright (C) 2000 - 2002  Kenzaburo Ito - kenito@300baud.org
-	# Copyright (C) 2002 - 2004  Mantis Team   - mantisbt-dev@lists.sourceforge.net
-	# This program is distributed under the terms and conditions of the GPL
-	# See the README and LICENSE files for details
+# Mantis - a php based bugtracking system
+
+# Copyright (C) 2000 - 2002  Kenzaburo Ito - kenito@300baud.org
+# Copyright (C) 2002 - 2007  Mantis Team   - mantisbt-dev@lists.sourceforge.net
+
+# Mantis is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation, either version 2 of the License, or
+# (at your option) any later version.
+#
+# Mantis is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with Mantis.  If not, see <http://www.gnu.org/licenses/>.
 
 	# --------------------------------------------------------
-	# $Id: print_bug_page.php,v 1.56.6.1 2006/01/01 02:58:50 thraxisp Exp $
+	# $Id: print_bug_page.php,v 1.60.2.1 2007-10-13 22:34:18 giallu Exp $
 	# --------------------------------------------------------
 ?>
 <?php
@@ -18,14 +30,11 @@
 	require_once( $t_core_path.'custom_field_api.php' );
 	require_once( $t_core_path.'date_api.php' );
 	require_once( $t_core_path.'string_api.php' );
+	require_once( $t_core_path.'last_visited_api.php' );
 ?>
 <?php
 	$f_bug_id = gpc_get_int( 'bug_id' );
 
-	if ( SIMPLE_ONLY == $g_show_view ) {
-		print_header_redirect ( 'bug_view_page.php?bug_id='.$f_bug_id );
-	}
-
 	access_ensure_bug_level( VIEWER, $f_bug_id );
 
 	$c_bug_id = (integer)$f_bug_id;
@@ -45,6 +54,8 @@
 	$result = db_query( $query );
 	$row = db_fetch_array( $result );
 	extract( $row, EXTR_PREFIX_ALL, 'v2' );
+	
+	$t_history = history_get_events_array( $f_bug_id );
 
 	$v_os 						= string_display( $v_os );
 	$v_os_build					= string_display( $v_os_build );
@@ -248,7 +259,7 @@ foreach( $t_related_custom_field_ids as $t_id ) {
 ?>
 <tr class="print">
 	<td class="print-category">
-		<?php echo lang_get_defaulted( $t_def['name'] ) ?>:
+		<?php echo string_display( lang_get_defaulted( $t_def['name'] ) ) ?>:
 	</td>
 	<td class="print" colspan="4">
 		<?php print_custom_field_value( $t_def, $t_id, $f_bug_id ); ?>
@@ -337,6 +348,57 @@ foreach( $t_related_custom_field_ids as $t_id ) {
 		<?php file_list_attachments ( $f_bug_id ); ?>
 	</td>
 </tr>
+<tr>
+	<td class="print-spacer" colspan="6">
+		<hr size="1" />
+	</td>
+</tr>
+<?php 
+	# ISSUE HISTORY 
+?>
+<tr>
+	<td class="form-title">
+		<?php echo lang_get( 'bug_history' ) ?>
+	</td>
+</tr>
+<tr class="print-category">
+	<td class="row-category-history">
+		<?php echo lang_get( 'date_modified' ) ?>
+	</td>
+	<td class="row-category-history">
+		<?php echo lang_get( 'username' ) ?>
+	</td>
+	<td class="row-category-history">
+		<?php echo lang_get( 'field' ) ?>
+	</td>
+	<td class="row-category-history">
+		<?php echo lang_get( 'change' ) ?>
+	</td>
+</tr>
+<?php
+	foreach ( $t_history as $t_item ) {
+?>
+<tr class="print">
+	<td class="print">
+		<?php echo $t_item['date'] ?>
+	</td>
+	<td  class="print">
+		<?php print_user( $t_item['userid'] ) ?>
+	</td>
+	<td class="print">
+		<?php echo string_display( $t_item['note'] ) ?>
+	</td>
+	<td class="print">
+		<?php echo string_display_line_links( $t_item['change'] ) ?>
+	</td>
+</tr>
+<?php
+	} 
+?>
 </table>
 
-<?php include( dirname( __FILE__ ) . DIRECTORY_SEPARATOR . 'print_bugnote_inc.php' ) ?>
+<?php
+	include( dirname( __FILE__ ) . DIRECTORY_SEPARATOR . 'print_bugnote_inc.php' ) ;
+
+	last_visited_issue( $f_bug_id );
+?>
